fn chosen_successor(path: &Path, block: BasicBlock) -> Option<BasicBlock>Expand description
Return the next MIR block after block in a finite verification path.
fn chosen_successor(path: &Path, block: BasicBlock) -> Option<BasicBlock>Return the next MIR block after block in a finite verification path.